:orphan:

See also
========

Here is a list of Python_ packages that deal with units and quantities, besides
natu_:

- `astropy.units <http://astropy.readthedocs.org/en/latest/units/>`_
- `Buckingham <http://code.google.com/p/buckingham/>`_
- `DimPy <http://www.inference.phy.cam.ac.uk/db410/>`_
- `Magnitude <http://juanreyero.com/open/magnitude/>`_
- `NumericalUnits <https://pypi.python.org/pypi/numericalunits>`_
- `Pint <http://pint.readthedocs.org/>`_
- `Python-quantities <https://pypi.python.org/pypi/quantities>`_
- `Scalar <http://russp.us/scalar-guide.htm>`_
- `Scientific.Physics.PhysicalQuantities <http://dirac.cnrs-orleans.fr/ScientificPython/ScientificPythonManual/Scientific.Physics.PhysicalQuantities-module.html>`_
- `SciMath <http://scimath.readthedocs.org/en/latest/units/intro.html>`_
- `sympy.physics.units <http://docs.sympy.org/dev/modules/physics/units.html>`_
- `udunitspy <https://github.com/blazetopher/udunitspy>`_
- `Units <https://bitbucket.org/adonohue/units/>`_
- `Unum <https://bitbucket.org/kiv/unum/>`_


.. _Python: http://www.python.org/
.. _natu: index.html
